@@ -1,8 +1,6 @@
-
 from abc import ABC, abstractmethod
 from typing import Any, List
 
-
 class BaseModel(ABC):
     '''Base class for models to inherit from
     '''
@@ -24,12 +22,13 @@ class BaseModel(ABC):
         
         
     def preprocess(self, items: List[Any]) -> List[Any]:
-        '''Preprecossing steps to convert raw data to form consumed by model
+        '''Preprocessing steps to convert raw data into the form required by your model
         
-        Precessing logic is suggested to put in this function. In this way metrics like counting
-        and duration will be handled correctly for preprecessong specific. 
-        This is not necessary. Default implementation is enought if you just want to
-        put every thing in predict function.
+        Put your precessing logic into this function so that metrics like counting
+        and duration will be handled correctly. For example, perform any JSON transformations
+        you need here
+
+        Default implementation is enough if you just want to put every thing in the 'predict' function.
         
         Args:
             items: Input data items
