@@ -64,7 +64,7 @@ def initialize(
             eh_structured: structured eventhub name. Default, read $EVENTHUB_AUX_STRUCTURED
             eh_unstructured: unstructured eventhub name. Default, read $EVENTHUB_AUX_UNSTRUCTURED
             role: role, Default: `RemoteModel`
-            instance: instance, Default: `${ENDPOINT_NAME}|${ENDPOINT_VERSION}|{hostname}` or `${ENDPOINT_NAME}|${ENDPOINT_VERSION}|{_probably_unique_id()}`
+            instance: instance, Default: `${MODEL_NAME}|${ENDPOINT_VERSION}|{hostname}` or `${MODEL_NAME}|${ENDPOINT_VERSION}|{_probably_unique_id()}`
             sys_metrics_enable: Whether to enable auto metrics reporting periodically for system info like gpu, memory and gpu. Default: True
         
         Note: 
@@ -98,16 +98,16 @@ def initialize(
             if role is None:
                 role = 'RemoteModel'
             if instance is None:
-                endpoint_name = os.getenv('ENDPOINT_NAME', 'unknown')
+                model_name = os.getenv('MODEL_NAME', 'unknown')
                 endpoint_version = os.getenv('ENDPOINT_VERSION', 'unknown')
                 # Using `socket.gethostname()` to get hostname, because `os.uname` doesn't work on windows, 
                 # and will be truncated in some systems. Even official doc of `os.uname` recommends to use 
                 # `socket.gethostname()`. https://docs.python.org/3.5/library/os.html#os.uname
                 hostname = socket.gethostname()
                 if len(hostname) <= 60:
-                    instance = f'{endpoint_name}|{endpoint_version}|{hostname}'
+                    instance = f'{model_name}|{endpoint_version}|{hostname}'
                 else:
-                    instance = f'{endpoint_name}|{endpoint_version}|{_probably_unique_id()}'
+                    instance = f'{model_name}|{endpoint_version}|{_probably_unique_id()}'
 
             
             # set variables
